@@ -1,10 +1,7 @@
 #!/usr/bin/env perl
 
-use feature 'say';
-use open qw(:std :utf8);
 use strict;
 use warnings;
-use warnings qw(FATAL utf8);
 
 use Set::Array;
 use Set::Scalar;
